import { useState, useRef, useEffect } from 'react';

var isShallowEqual = function isShallowEqual(newValue, oldValue) {
  return newValue === oldValue;
};

function areInputsEqual(newInputs, lastInputs) {
  return newInputs.length === lastInputs.length && newInputs.every(function (newArg, index) {
    return isShallowEqual(newArg, lastInputs[index]);
  });
}

function useMemoOne(getResult, inputs) {
  if (inputs === void 0) {
    inputs = [];
  }

  var initial = useState(function () {
    return {
      inputs: inputs,
      result: getResult()
    };
  })[0];
  var uncommitted = useRef(initial);
  var committed = useRef(initial);
  useEffect(function () {
    committed.current = uncommitted.current;
  });

  if (areInputsEqual(inputs, committed.current.inputs)) {
    return committed.current.result;
  }

  uncommitted.current = {
    inputs: inputs,
    result: getResult()
  };
  return uncommitted.current.result;
}
function useCallbackOne(callback, inputs) {
  if (inputs === void 0) {
    inputs = [];
  }

  return useMemoOne(function () {
    return callback;
  }, inputs);
}

export { useCallbackOne, useMemoOne };
